from django.core.management.base import BaseCommand

from clearcache.utils import clear_cache


class Command(BaseCommand):
    help = 'Clears cache_id'

    def add_arguments(self, parser):
        parser.add_argument('cache_name', nargs='?', type=str)

    def handle(self, *args, **options):
        cache_name = options['cache_name'] or 'default'
        try:
            clear_cache(cache_name)
            self.stdout.write(self.style.SUCCESS(f'Successfully cleared "{cache_name}" cache'))
        except Exception as err:
            self.stderr.write(self.style.ERROR(err))



import time

import pytest
from django.core.cache import cache
from django.core.management import call_command
from django.urls import reverse

CACHE_KEY = 'example_cache_key'
CACHE_VALUE = 'example_cache_value'


def test_cache_works():
    CACHE_EXPIRE_IN_SEC = 1

    assert cache.get(CACHE_KEY) is None, "The value isn't cached yet"

    cache.set(CACHE_KEY, CACHE_VALUE, CACHE_EXPIRE_IN_SEC)
    assert cache.get(CACHE_KEY) == CACHE_VALUE, "The value came from a cache"

    time.sleep(1)
    assert cache.get(CACHE_KEY) is None, "The value isn't cached because it's expired"


def test_clears_cache_via_command_line():
    cache.set(CACHE_KEY, CACHE_VALUE, 100)
    assert cache.get(CACHE_KEY) == CACHE_VALUE, "Cache populated"

    call_command('clearcache')

    assert cache.get(CACHE_KEY) is None, "Cache cleared"


@pytest.mark.django_db
def test_clear_cache_is_in_admin_index(admin_client):
    response = admin_client.get('/admin/')
    assert "Clear cache" in str(response.content)


@pytest.mark.django_db
def test_clear_cache_form_is_rendered(admin_client):
    response = admin_client.get(reverse('clearcache_admin'))
    assert "Clear cache now" in str(response.content), "Clear cache now button is visible"


@pytest.mark.django_db
def test_non_superuser_cant_access_clearcache(client):
    response = client.get(reverse('clearcache_admin'))
    assert response.status_code == 302


@pytest.mark.django_db
def test_clears_cache_via_admin_ui(admin_client):
    cache.set(CACHE_KEY, CACHE_VALUE, 100)
    assert cache.get(CACHE_KEY) == CACHE_VALUE, "Cache populated"

    admin_client.post(reverse('clearcache_admin'), {
        'cache_name': 'default'
    })

    assert cache.get(CACHE_KEY) is None, "Cache cleared"



from django import forms
from django.conf import settings


def get_cache_choices():
    caches = settings.CACHES or {}
    return [(key, f"{key} ({cache['BACKEND']}") for key, cache in caches.items()]


class ClearCacheForm(forms.Form):
    cache_name = forms.ChoiceField(choices=get_cache_choices)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['clearcache', 'clearcache.management', 'clearcache.management.commands']

package_data = \
{'': ['*'], 'clearcache': ['templates/admin/*', 'templates/clearcache/admin/*']}

install_requires = \
['django>=2.2,<3.1']

setup_kwargs = {
    'name': 'django-clearcache',
    'version': '1.0.1',
    'description': 'Allows you to clear Django cache via admin UI or manage.py command',
    'long_description': "# Django ClearCache\n\nAllows you to clear Django cache via admin UI or manage.py command.\n\n![demo](http://g.recordit.co/qnrHAo66Ny.gif)\n\n## Installation\n\n1. Install using PIP:\n\n    `pip install django-clearcache`\n\n2. Add **clearcache** to INSTALLED_APPS, make sure it's above `django.contrib.admin`:\n\n```\nINSTALLED_APPS += [\n    ...\n    'clearcache',\n    'django.contrib.admin',\n    ...\n]\n```\n\n3. Add url to the main **urls.py** right above root admin url:\n    ```\n    urlpatterns = [\n        url(r'^admin/clearcache/', include('clearcache.urls')),\n        url(r'^admin/', include(admin.site.urls)),\n    ]\n    ```\n\n## Usage\n\n### Via Django admin\n\n1. Go to `/admin/clearcache/`, you should see a form with cache selector\n2. Pick a cache. Usually there's one default cache, but can be more.\n3. Click the button, you're done!\n\n### Via manage.py command\n\n1. Run the following command to clear the default cache\n\n```\npython manage.py clearcache\n```\n\n2. Run the command above with an additional parameter to clear non-default cache (if exists):\n\n```\npython manage.py clearcache cache_name\n```\n\n## Follow me\n\n1. Check my dev blog with Python and JavaScript tutorials at [https://timonweb.com](https://timonweb.com)\n2. Follow me on twitter [@timonweb](https://twitter.com/timonweb)\n",
    'author': 'Tim Kamanin',
    'author_email': 'tim@timonweb.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://timonweb.com',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<3.9',
}


setup(**setup_kwargs)
